@@ -1,11 +1,11 @@
 package Yancy::Util;
-our $VERSION = '1.082';
+our $VERSION = '1.083';
 # ABSTRACT: Utilities for Yancy
 
 #pod =head1 SYNOPSIS
 #pod
 #pod     use Yancy::Util qw( load_backend );
-#pod     my $be = load_backend( 'test://localhost', $schema );
+#pod     my $be = load_backend( 'memory://localhost', $schema );
 #pod
 #pod     use Yancy::Util qw( curry );
 #pod     my $helper = curry( \&_helper_sub, @args );
@@ -521,12 +521,12 @@ Yancy::Util - Utilities for Yancy
 
 =head1 VERSION
 
-version 1.082
+version 1.083
 
 =head1 SYNOPSIS
 
     use Yancy::Util qw( load_backend );
-    my $be = load_backend( 'test://localhost', $schema );
+    my $be = load_backend( 'memory://localhost', $schema );
 
     use Yancy::Util qw( curry );
     my $helper = curry( \&_helper_sub, @args );
